#!/usr/bin/python
#
# Copyright 2018-2020 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from polyaxon.schemas.fields.dict_or_str import DictOrStr  # noqa
from polyaxon.schemas.fields.float_or_str import FloatOrStr  # noqa
from polyaxon.schemas.fields.indexed_dict import IndexedDict  # noqa
from polyaxon.schemas.fields.int_or_str import IntOrStr  # noqa
from polyaxon.schemas.fields.obj_list_obj import ObjectOrListObject  # noqa
from polyaxon.schemas.fields.str_or_fct import StrOrFct  # noqa
from polyaxon.schemas.fields.tensor import Tensor  # noqa
from polyaxon.schemas.fields.uuids import UUID  # noqa
